{ config, pkgs, ... }:

{
  # Nombre de process d'installation en parrallèle effectués par Nix
  nix.buildCores = 0;

  # The NixOS release to be compatible with for stateful data such as databases.
  system.stateVersion = "16.03";

  # On autorise les paquets non-libres
  nixpkgs.config.allowUnfree = true;

  # List packages installed in system profile. To search by name, run:
  # $ nix-env -qaP | grep wget
  environment = {
    systemPackages = with pkgs; [
      bind          # utilisé pour les utilitaires comme dig
      byobu         # permet de se déconnecter d'un terminal sans l'aréter
      exfat         # Pour monter les FAT avec Fuse
      git gitAndTools.gitSVN gitAndTools.tig # outil de gestion de version
      gnumake       # pour décrire les recettes de compilation
      gnupg         # GPG
      gpm           # prise en charge de la souris en console
      htop          # monitoring
      ncdu          # outil pour voir l'espace utilisé
      nmap          # outil de scan de port réseau
      mtr           # outil de diagnostic réseau
      p7zip         # compression de fichier
      parted        # partitionnement de disque
      pciutils
      python34Packages.glances # monitoring
      pwgen         # générateur de mot de passe
      tmux          # nécessaire pour byobu
      tree          # affiche une arborescence de fichiers et dossiers
      usbutils
      (import ./vim.nix)
      wget          # client HTTP console
      which         # pour connaitre le chemin d'un exécutable
    ];
    shellAliases = {
      byobu = "byobu-tmux";
      tree = "tree -C";
      tree1 = "tree -d -L 1";
      tree2 = "tree -d -L 2";
      tree3 = "tree -d -L 3";
      grep = "grep --color=auto";
      vi = "vim";
    };
    etc.gitconfig.text = builtins.readFile ./gitconfig;
  };
  programs.bash = {
    enableCompletion = true;
    promptInit = builtins.readFile ./bash-prompt.sh;
    interactiveShellInit = builtins.readFile ./bash-interactive-init.sh;
  };
}
